==> forestry_1.10.2-5.2.13.261-sources.jar: forestry/factory/gui/GuiStill.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.factory.gui;

import net.minecraft.entity.player.InventoryPlayer;

import forestry.core.config.Constants;
import forestry.core.gui.GuiForestryTitled;
import forestry.core.gui.widgets.TankWidget;
import forestry.factory.tiles.TileStill;

public class GuiStill extends GuiForestryTitled<ContainerStill, TileStill> {

	public GuiStill(InventoryPlayer inventory, TileStill tile) {
		super(Constants.TEXTURE_PATH_GUI + "/still.png", new ContainerStill(inventory, tile), tile);
		widgetManager.add(new TankWidget(this.widgetManager, 35, 15, 0));
		widgetManager.add(new TankWidget(this.widgetManager, 125, 15, 1));
	}

	@Override
	protected void func_146976_a(float var1, int mouseX, int mouseY) {
		super.func_146976_a(var1, mouseX, mouseY);
		TileStill still = inventory;

		func_73729_b(field_147003_i + 81, field_147009_r + 57, 176, 60, 14, 14);

		if (still.getWorkCounter() > 0) {
			int massRemaining = still.getProgressScaled(16);
			func_73729_b(field_147003_i + 84, field_147009_r + 17 + massRemaining, 176, 74 + massRemaining, 4, 17 - massRemaining);
		}
	}

}

==> forestry_1.11.2-5.3.4.130-sources.jar: forestry/factory/gui/GuiStill.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.factory.gui;

import forestry.core.config.Constants;
import forestry.core.gui.GuiForestryTitled;
import forestry.core.gui.widgets.TankWidget;
import forestry.factory.tiles.TileStill;
import net.minecraft.entity.player.InventoryPlayer;

public class GuiStill extends GuiForestryTitled<ContainerStill> {
	private final TileStill tile;

	public GuiStill(InventoryPlayer inventory, TileStill tile) {
		super(Constants.TEXTURE_PATH_GUI + "/still.png", new ContainerStill(inventory, tile), tile);
		this.tile = tile;
		widgetManager.add(new TankWidget(this.widgetManager, 35, 15, 0));
		widgetManager.add(new TankWidget(this.widgetManager, 125, 15, 1));
	}

	@Override
	protected void func_146976_a(float var1, int mouseX, int mouseY) {
		super.func_146976_a(var1, mouseX, mouseY);

		func_73729_b(field_147003_i + 81, field_147009_r + 57, 176, 60, 14, 14);

		if (tile.getWorkCounter() > 0) {
			int massRemaining = tile.getProgressScaled(16);
			func_73729_b(field_147003_i + 84, field_147009_r + 17 + massRemaining, 176, 74 + massRemaining, 4, 17 - massRemaining);
		}
	}

	@Override
	protected void addLedgers() {
		addErrorLedger(tile);
		addHintLedger("still");
		addPowerLedger(tile.getEnergyManager());
	}
}
